@@ -145,7 +145,7 @@ char* gtkaml_code_generator_yield (GtkamlCodeGenerator* self) {
 		for (; i < gtkaml_root_class_definition_get_original_first_code_line (self->priv->_root_class_definition); i++) {
 			char* _tmp5;
 			_tmp5 = NULL;
-			yielded = (_tmp5 = g_strconcat (yielded, ("\n"), NULL), yielded = (g_free (yielded), NULL), _tmp5);
+			yielded = (_tmp5 = g_strconcat (yielded, "\n", NULL), yielded = (g_free (yielded), NULL), _tmp5);
 		}
 	}
 	_tmp18 = NULL;
@@ -161,7 +161,7 @@ char* gtkaml_code_generator_yield (GtkamlCodeGenerator* self) {
 	_tmp8 = NULL;
 	_tmp7 = NULL;
 	_tmp6 = NULL;
-	yielded = (_tmp18 = g_strconcat (yielded, _tmp17 = (g_strconcat (_tmp16 = g_strconcat (_tmp15 = g_strconcat (_tmp14 = g_strconcat (_tmp13 = g_strconcat (_tmp12 = g_strconcat (_tmp11 = g_strconcat (_tmp10 = g_strconcat (_tmp9 = g_strconcat (_tmp8 = g_strconcat (_tmp7 = g_strconcat (_tmp6 = g_strconcat (self->priv->code, "\n", NULL), self->priv->construct_signals, NULL), "\n", NULL), "\tconstruct {\n", NULL), self->priv->construct_body_locals, NULL), "\n", NULL), self->priv->constructors, NULL), "\n", NULL), self->priv->construct_body, NULL), "\n", NULL), "\t}\n", NULL), self->priv->class_end, NULL)), NULL), yielded = (g_free (yielded), NULL), _tmp18);
+	yielded = (_tmp18 = g_strconcat (yielded, _tmp17 = g_strconcat (_tmp16 = g_strconcat (_tmp15 = g_strconcat (_tmp14 = g_strconcat (_tmp13 = g_strconcat (_tmp12 = g_strconcat (_tmp11 = g_strconcat (_tmp10 = g_strconcat (_tmp9 = g_strconcat (_tmp8 = g_strconcat (_tmp7 = g_strconcat (_tmp6 = g_strconcat (self->priv->code, "\n", NULL), self->priv->construct_signals, NULL), "\n", NULL), "\tconstruct {\n", NULL), self->priv->construct_body_locals, NULL), "\n", NULL), self->priv->constructors, NULL), "\n", NULL), self->priv->construct_body, NULL), "\n", NULL), "\t}\n", NULL), self->priv->class_end, NULL), NULL), yielded = (g_free (yielded), NULL), _tmp18);
 	_tmp17 = (g_free (_tmp17), NULL);
 	_tmp16 = (g_free (_tmp16), NULL);
 	_tmp15 = (g_free (_tmp15), NULL);
@@ -334,7 +334,7 @@ void gtkaml_code_generator_write_construct_call (GtkamlCodeGenerator* self, cons
 	}
 	_tmp7 = NULL;
 	_tmp6 = NULL;
-	self->priv->construct_signals = (_tmp7 = g_strconcat (self->priv->construct_signals, _tmp6 = (g_strdup_printf ("\tprivate signal void %s (%s target);\n", construct_signal, identifier_type)), NULL), self->priv->construct_signals = (g_free (self->priv->construct_signals), NULL), _tmp7);
+	self->priv->construct_signals = (_tmp7 = g_strconcat (self->priv->construct_signals, _tmp6 = g_strdup_printf ("\tprivate signal void %s (%s target);\n", construct_signal, identifier_type), NULL), self->priv->construct_signals = (g_free (self->priv->construct_signals), NULL), _tmp7);
 	_tmp6 = (g_free (_tmp6), NULL);
 	_tmp12 = NULL;
 	_tmp11 = NULL;
@@ -346,11 +346,11 @@ void gtkaml_code_generator_write_construct_call (GtkamlCodeGenerator* self, cons
 	if (_vala_strcmp0 (construct_type, "preconstruct") == 0) {
 		char* _tmp14;
 		_tmp14 = NULL;
-		self->priv->constructors = (_tmp14 = g_strconcat (self->priv->constructors, (to_append), NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp14);
+		self->priv->constructors = (_tmp14 = g_strconcat (self->priv->constructors, to_append, NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp14);
 	} else {
 		char* _tmp15;
 		_tmp15 = NULL;
-		self->priv->construct_body = (_tmp15 = g_strconcat (self->priv->construct_body, (to_append), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp15);
+		self->priv->construct_body = (_tmp15 = g_strconcat (self->priv->construct_body, to_append, NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp15);
 	}
 	construct_signal = (g_free (construct_signal), NULL);
 	real_construct_code = (g_free (real_construct_code), NULL);
@@ -373,7 +373,7 @@ void gtkaml_code_generator_write_complex_attributes (GtkamlCodeGenerator* self,
 			if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 				GtkamlAttribute* _tmp0;
 				_tmp0 = NULL;
-				gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL))));
+				gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type ((_tmp0 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL)));
 			}
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
@@ -395,7 +395,7 @@ void gtkaml_code_generator_write_complex_attributes (GtkamlCodeGenerator* self,
 				if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 					GtkamlAttribute* _tmp2;
 					_tmp2 = NULL;
-					gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp2 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp2) ? ((GtkamlComplexAttribute*) _tmp2) : NULL))));
+					gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type ((_tmp2 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp2) ? ((GtkamlComplexAttribute*) _tmp2) : NULL)));
 				}
 				(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 			}
@@ -427,7 +427,7 @@ void gtkaml_code_generator_write_complex_attributes (GtkamlCodeGenerator* self,
 				if (_tmp4) {
 					GtkamlAttribute* _tmp5;
 					_tmp5 = NULL;
-					gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp5 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp5) ? ((GtkamlComplexAttribute*) _tmp5) : NULL))));
+					gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type ((_tmp5 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp5) ? ((GtkamlComplexAttribute*) _tmp5) : NULL)));
 				}
 				first = FALSE;
 				(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
@@ -464,41 +464,41 @@ void gtkaml_code_generator_write_root_class_definition (GtkamlCodeGenerator* sel
 	_tmp3 = NULL;
 	base_name = (_tmp3 = vala_symbol_get_name ((ValaSymbol*) gtkaml_class_definition_get_base_type ((GtkamlClassDefinition*) root_class_definition)), (_tmp3 == NULL) ? NULL : g_strdup (_tmp3));
 	_tmp4 = NULL;
-	self->priv->class_start = (_tmp4 = g_strconcat (self->priv->class_start, ("public class "), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp4);
+	self->priv->class_start = (_tmp4 = g_strconcat (self->priv->class_start, "public class ", NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp4);
 	if (ns != NULL) {
 		char* _tmp6;
 		char* _tmp5;
 		_tmp6 = NULL;
 		_tmp5 = NULL;
-		self->priv->class_start = (_tmp6 = g_strconcat (self->priv->class_start, _tmp5 = (g_strconcat (ns, ".", NULL)), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp6);
+		self->priv->class_start = (_tmp6 = g_strconcat (self->priv->class_start, _tmp5 = g_strconcat (ns, ".", NULL), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp6);
 		_tmp5 = (g_free (_tmp5), NULL);
 	}
 	_tmp8 = NULL;
 	_tmp7 = NULL;
-	self->priv->class_start = (_tmp8 = g_strconcat (self->priv->class_start, _tmp7 = (g_strconcat (name, " : ", NULL)), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp8);
+	self->priv->class_start = (_tmp8 = g_strconcat (self->priv->class_start, _tmp7 = g_strconcat (name, " : ", NULL), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp8);
 	_tmp7 = (g_free (_tmp7), NULL);
 	if (base_ns != NULL) {
 		char* _tmp10;
 		char* _tmp9;
 		_tmp10 = NULL;
 		_tmp9 = NULL;
-		self->priv->class_start = (_tmp10 = g_strconcat (self->priv->class_start, _tmp9 = (g_strconcat (base_ns, ".", NULL)), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp10);
+		self->priv->class_start = (_tmp10 = g_strconcat (self->priv->class_start, _tmp9 = g_strconcat (base_ns, ".", NULL), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp10);
 		_tmp9 = (g_free (_tmp9), NULL);
 	}
 	_tmp11 = NULL;
-	self->priv->class_start = (_tmp11 = g_strconcat (self->priv->class_start, (base_name), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp11);
+	self->priv->class_start = (_tmp11 = g_strconcat (self->priv->class_start, base_name, NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp11);
 	if (gtkaml_root_class_definition_get_implements (root_class_definition) != NULL) {
 		char* _tmp13;
 		char* _tmp12;
 		_tmp13 = NULL;
 		_tmp12 = NULL;
-		self->priv->class_start = (_tmp13 = g_strconcat (self->priv->class_start, _tmp12 = (g_strconcat (", ", gtkaml_root_class_definition_get_implements (root_class_definition), NULL)), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp13);
+		self->priv->class_start = (_tmp13 = g_strconcat (self->priv->class_start, _tmp12 = g_strconcat (", ", gtkaml_root_class_definition_get_implements (root_class_definition), NULL), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp13);
 		_tmp12 = (g_free (_tmp12), NULL);
 	}
 	_tmp14 = NULL;
-	self->priv->class_start = (_tmp14 = g_strconcat (self->priv->class_start, ("\n{\n"), NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp14);
+	self->priv->class_start = (_tmp14 = g_strconcat (self->priv->class_start, "\n{\n", NULL), self->priv->class_start = (g_free (self->priv->class_start), NULL), _tmp14);
 	_tmp15 = NULL;
-	self->priv->class_end = (_tmp15 = g_strconcat (self->priv->class_end, ("}\n"), NULL), self->priv->class_end = (g_free (self->priv->class_end), NULL), _tmp15);
+	self->priv->class_end = (_tmp15 = g_strconcat (self->priv->class_end, "}\n", NULL), self->priv->class_end = (g_free (self->priv->class_end), NULL), _tmp15);
 	{
 		GeeIterator* _code_it;
 		_code_it = gee_iterable_iterator ((GeeIterable*) gtkaml_root_class_definition_get_code (root_class_definition));
@@ -535,7 +535,7 @@ void gtkaml_code_generator_write_declaration (GtkamlCodeGenerator* self, GtkamlC
 			_tmp2 = NULL;
 			_tmp1 = NULL;
 			_tmp0 = NULL;
-			self->priv->members_declarations = (_tmp5 = g_strconcat (self->priv->members_declarations, _tmp4 = (g_strconcat (_tmp3 = g_strconcat (_tmp2 = g_strconcat (_tmp1 = g_strconcat ("\tpublic ", _tmp0 = gtkaml_class_definition_get_base_full_name (class_definition), NULL), " ", NULL), gtkaml_class_definition_get_identifier (class_definition), NULL), ";\n", NULL)), NULL), self->priv->members_declarations = (g_free (self->priv->members_declarations), NULL), _tmp5);
+			self->priv->members_declarations = (_tmp5 = g_strconcat (self->priv->members_declarations, _tmp4 = g_strconcat (_tmp3 = g_strconcat (_tmp2 = g_strconcat (_tmp1 = g_strconcat ("\tpublic ", _tmp0 = gtkaml_class_definition_get_base_full_name (class_definition), NULL), " ", NULL), gtkaml_class_definition_get_identifier (class_definition), NULL), ";\n", NULL), NULL), self->priv->members_declarations = (g_free (self->priv->members_declarations), NULL), _tmp5);
 			_tmp4 = (g_free (_tmp4), NULL);
 			_tmp3 = (g_free (_tmp3), NULL);
 			_tmp2 = (g_free (_tmp2), NULL);
@@ -557,7 +557,7 @@ void gtkaml_code_generator_write_declaration (GtkamlCodeGenerator* self, GtkamlC
 			_tmp8 = NULL;
 			_tmp7 = NULL;
 			_tmp6 = NULL;
-			self->priv->members_declarations = (_tmp11 = g_strconcat (self->priv->members_declarations, _tmp10 = (g_strconcat (_tmp9 = g_strconcat (_tmp8 = g_strconcat (_tmp7 = g_strconcat ("\tprivate ", _tmp6 = gtkaml_class_definition_get_base_full_name (class_definition), NULL), " ", NULL), gtkaml_class_definition_get_identifier (class_definition), NULL), ";\n", NULL)), NULL), self->priv->members_declarations = (g_free (self->priv->members_declarations), NULL), _tmp11);
+			self->priv->members_declarations = (_tmp11 = g_strconcat (self->priv->members_declarations, _tmp10 = g_strconcat (_tmp9 = g_strconcat (_tmp8 = g_strconcat (_tmp7 = g_strconcat ("\tprivate ", _tmp6 = gtkaml_class_definition_get_base_full_name (class_definition), NULL), " ", NULL), gtkaml_class_definition_get_identifier (class_definition), NULL), ";\n", NULL), NULL), self->priv->members_declarations = (g_free (self->priv->members_declarations), NULL), _tmp11);
 			_tmp10 = (g_free (_tmp10), NULL);
 			_tmp9 = (g_free (_tmp9), NULL);
 			_tmp8 = (g_free (_tmp8), NULL);
@@ -579,7 +579,7 @@ void gtkaml_code_generator_write_declaration (GtkamlCodeGenerator* self, GtkamlC
 			_tmp14 = NULL;
 			_tmp13 = NULL;
 			_tmp12 = NULL;
-			self->priv->construct_body_locals = (_tmp17 = g_strconcat (self->priv->construct_body_locals, _tmp16 = (g_strconcat (_tmp15 = g_strconcat (_tmp14 = g_strconcat (_tmp13 = g_strconcat ("\t\t", _tmp12 = gtkaml_class_definition_get_base_full_name (class_definition), NULL), " ", NULL), gtkaml_class_definition_get_identifier (class_definition), NULL), ";\n", NULL)), NULL), self->priv->construct_body_locals = (g_free (self->priv->construct_body_locals), NULL), _tmp17);
+			self->priv->construct_body_locals = (_tmp17 = g_strconcat (self->priv->construct_body_locals, _tmp16 = g_strconcat (_tmp15 = g_strconcat (_tmp14 = g_strconcat (_tmp13 = g_strconcat ("\t\t", _tmp12 = gtkaml_class_definition_get_base_full_name (class_definition), NULL), " ", NULL), gtkaml_class_definition_get_identifier (class_definition), NULL), ";\n", NULL), NULL), self->priv->construct_body_locals = (g_free (self->priv->construct_body_locals), NULL), _tmp17);
 			_tmp16 = (g_free (_tmp16), NULL);
 			_tmp15 = (g_free (_tmp15), NULL);
 			_tmp14 = (g_free (_tmp14), NULL);
@@ -640,7 +640,7 @@ void gtkaml_code_generator_write_constructor (GtkamlCodeGenerator* self, GtkamlC
 	_tmp5 = NULL;
 	_tmp4 = NULL;
 	_tmp3 = NULL;
-	self->priv->constructors = (_tmp9 = g_strconcat (self->priv->constructors, _tmp8 = (g_strconcat (_tmp7 = g_strconcat (_tmp6 = g_strconcat (_tmp4 = g_strconcat (_tmp3 = g_strconcat ("\t\t", gtkaml_class_definition_get_identifier (class_definition), NULL), " = new ", NULL), _tmp5 = gtkaml_class_definition_get_base_full_name (class_definition), NULL), construct_name, NULL), " (", NULL)), NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp9);
+	self->priv->constructors = (_tmp9 = g_strconcat (self->priv->constructors, _tmp8 = g_strconcat (_tmp7 = g_strconcat (_tmp6 = g_strconcat (_tmp4 = g_strconcat (_tmp3 = g_strconcat ("\t\t", gtkaml_class_definition_get_identifier (class_definition), NULL), " = new ", NULL), _tmp5 = gtkaml_class_definition_get_base_full_name (class_definition), NULL), construct_name, NULL), " (", NULL), NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp9);
 	_tmp8 = (g_free (_tmp8), NULL);
 	_tmp7 = (g_free (_tmp7), NULL);
 	_tmp6 = (g_free (_tmp6), NULL);
@@ -657,7 +657,7 @@ void gtkaml_code_generator_write_constructor (GtkamlCodeGenerator* self, GtkamlC
 		_tmp12 = NULL;
 		_tmp11 = NULL;
 		_tmp10 = NULL;
-		self->priv->constructors = (_tmp12 = g_strconcat (self->priv->constructors, _tmp11 = (g_strconcat (_tmp10 = gtkaml_code_generator_generate_literal (self, attr), ", ", NULL)), NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp12);
+		self->priv->constructors = (_tmp12 = g_strconcat (self->priv->constructors, _tmp11 = g_strconcat (_tmp10 = gtkaml_code_generator_generate_literal (self, attr), ", ", NULL), NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp12);
 		_tmp11 = (g_free (_tmp11), NULL);
 		_tmp10 = (g_free (_tmp10), NULL);
 		(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
@@ -669,12 +669,12 @@ void gtkaml_code_generator_write_constructor (GtkamlCodeGenerator* self, GtkamlC
 		_tmp15 = NULL;
 		_tmp14 = NULL;
 		_tmp13 = NULL;
-		self->priv->constructors = (_tmp15 = g_strconcat (self->priv->constructors, _tmp14 = (gtkaml_code_generator_generate_literal (self, _tmp13 = (GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_construct_method (class_definition)), i))), NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp15);
+		self->priv->constructors = (_tmp15 = g_strconcat (self->priv->constructors, _tmp14 = gtkaml_code_generator_generate_literal (self, _tmp13 = (GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_construct_method (class_definition)), i)), NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp15);
 		_tmp14 = (g_free (_tmp14), NULL);
 		(_tmp13 == NULL) ? NULL : (_tmp13 = (g_object_unref (_tmp13), NULL));
 	}
 	_tmp16 = NULL;
-	self->priv->constructors = (_tmp16 = g_strconcat (self->priv->constructors, (");\n"), NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp16);
+	self->priv->constructors = (_tmp16 = g_strconcat (self->priv->constructors, ");\n", NULL), self->priv->constructors = (g_free (self->priv->constructors), NULL), _tmp16);
 	construct_name = (g_free (construct_name), NULL);
 }
 
@@ -691,7 +691,7 @@ void gtkaml_code_generator_write_add (GtkamlCodeGenerator* self, GtkamlClassDefi
 	}
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->construct_body = (_tmp1 = g_strconcat (self->priv->construct_body, _tmp0 = (g_strdup_printf ("\t\t%s.%s (", gtkaml_class_definition_get_identifier (gtkaml_class_definition_get_parent_container (child_definition)), gtkaml_method_get_name ((GtkamlMethod*) gtkaml_class_definition_get_add_method (child_definition)))), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp1);
+	self->priv->construct_body = (_tmp1 = g_strconcat (self->priv->construct_body, _tmp0 = g_strdup_printf ("\t\t%s.%s (", gtkaml_class_definition_get_identifier (gtkaml_class_definition_get_parent_container (child_definition)), gtkaml_method_get_name ((GtkamlMethod*) gtkaml_class_definition_get_add_method (child_definition))), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp1);
 	_tmp0 = (g_free (_tmp0), NULL);
 	i = 0;
 	for (; i < (gee_collection_get_size ((GeeCollection*) gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_add_method (child_definition))) - 1); i++) {
@@ -703,7 +703,7 @@ void gtkaml_code_generator_write_add (GtkamlCodeGenerator* self, GtkamlClassDefi
 		_tmp4 = NULL;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		self->priv->construct_body = (_tmp4 = g_strconcat (self->priv->construct_body, _tmp3 = (g_strconcat (_tmp2 = gtkaml_code_generator_generate_literal (self, attr), ", ", NULL)), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp4);
+		self->priv->construct_body = (_tmp4 = g_strconcat (self->priv->construct_body, _tmp3 = g_strconcat (_tmp2 = gtkaml_code_generator_generate_literal (self, attr), ", ", NULL), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp4);
 		_tmp3 = (g_free (_tmp3), NULL);
 		_tmp2 = (g_free (_tmp2), NULL);
 		(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
@@ -715,12 +715,12 @@ void gtkaml_code_generator_write_add (GtkamlCodeGenerator* self, GtkamlClassDefi
 		_tmp7 = NULL;
 		_tmp6 = NULL;
 		_tmp5 = NULL;
-		self->priv->construct_body = (_tmp7 = g_strconcat (self->priv->construct_body, _tmp6 = (gtkaml_code_generator_generate_literal (self, _tmp5 = (GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_add_method (child_definition)), i))), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp7);
+		self->priv->construct_body = (_tmp7 = g_strconcat (self->priv->construct_body, _tmp6 = gtkaml_code_generator_generate_literal (self, _tmp5 = (GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes ((GtkamlMethod*) gtkaml_class_definition_get_add_method (child_definition)), i)), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp7);
 		_tmp6 = (g_free (_tmp6), NULL);
 		(_tmp5 == NULL) ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL));
 	}
 	_tmp8 = NULL;
-	self->priv->construct_body = (_tmp8 = g_strconcat (self->priv->construct_body, (");\n"), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp8);
+	self->priv->construct_body = (_tmp8 = g_strconcat (self->priv->construct_body, ");\n", NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp8);
 }
 
 
@@ -764,7 +764,7 @@ char* gtkaml_code_generator_prefix_to_namespace (GtkamlCodeGenerator* self, cons
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (prefix != NULL, NULL);
 	_tmp0 = NULL;
-	if ((prefix == NULL)) {
+	if (prefix == NULL) {
 		_tmp0 = "";
 	} else {
 		_tmp0 = prefix;
@@ -780,7 +780,7 @@ void gtkaml_code_generator_write_using (GtkamlCodeGenerator* self, const char* n
 	g_return_if_fail (ns != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->using_directives = (_tmp1 = g_strconcat (self->priv->using_directives, _tmp0 = (g_strdup_printf ("using %s;\n", ns)), NULL), self->priv->using_directives = (g_free (self->priv->using_directives), NULL), _tmp1);
+	self->priv->using_directives = (_tmp1 = g_strconcat (self->priv->using_directives, _tmp0 = g_strdup_printf ("using %s;\n", ns), NULL), self->priv->using_directives = (g_free (self->priv->using_directives), NULL), _tmp1);
 	_tmp0 = (g_free (_tmp0), NULL);
 }
 
@@ -805,11 +805,11 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		_tmp2 = NULL;
-		return (_tmp2 = (_tmp1 = gtkaml_class_definition_get_identifier (gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL)))), (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), literal = (g_free (literal), NULL), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp2);
+		return (_tmp2 = (_tmp1 = gtkaml_class_definition_get_identifier (gtkaml_complex_attribute_get_complex_type ((_tmp0 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL))), (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), literal = (g_free (literal), NULL), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp2);
 	}
 	_tmp4 = NULL;
 	_tmp3 = NULL;
-	value = (_tmp4 = gtkaml_simple_attribute_get_value (((_tmp3 = attr, GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp3) ? ((GtkamlSimpleAttribute*) _tmp3) : NULL))), (_tmp4 == NULL) ? NULL : g_strdup (_tmp4));
+	value = (_tmp4 = gtkaml_simple_attribute_get_value ((_tmp3 = attr, GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp3) ? ((GtkamlSimpleAttribute*) _tmp3) : NULL)), (_tmp4 == NULL) ? NULL : g_strdup (_tmp4));
 	if (VALA_IS_FIELD (gtkaml_attribute_get_target_type (attr))) {
 		ValaDataType* _tmp7;
 		ValaDataType* _tmp6;
@@ -817,7 +817,7 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 		_tmp7 = NULL;
 		_tmp6 = NULL;
 		_tmp5 = NULL;
-		type = (_tmp7 = (_tmp6 = vala_field_get_field_type (((_tmp5 = gtkaml_attribute_get_target_type (attr), VALA_IS_FIELD (_tmp5) ? ((ValaField*) _tmp5) : NULL))), (_tmp6 == NULL) ? NULL : vala_code_node_ref (_tmp6)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp7);
+		type = (_tmp7 = (_tmp6 = vala_field_get_field_type ((_tmp5 = gtkaml_attribute_get_target_type (attr), VALA_IS_FIELD (_tmp5) ? ((ValaField*) _tmp5) : NULL)), (_tmp6 == NULL) ? NULL : vala_code_node_ref (_tmp6)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp7);
 	} else {
 		if (VALA_IS_PROPERTY (gtkaml_attribute_get_target_type (attr))) {
 			ValaDataType* _tmp10;
@@ -826,7 +826,7 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 			_tmp10 = NULL;
 			_tmp9 = NULL;
 			_tmp8 = NULL;
-			type = (_tmp10 = (_tmp9 = vala_property_get_property_type (((_tmp8 = gtkaml_attribute_get_target_type (attr), VALA_IS_PROPERTY (_tmp8) ? ((ValaProperty*) _tmp8) : NULL))), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp10);
+			type = (_tmp10 = (_tmp9 = vala_property_get_property_type ((_tmp8 = gtkaml_attribute_get_target_type (attr), VALA_IS_PROPERTY (_tmp8) ? ((ValaProperty*) _tmp8) : NULL)), (_tmp9 == NULL) ? NULL : vala_code_node_ref (_tmp9)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp10);
 		} else {
 			if (VALA_IS_FORMAL_PARAMETER (gtkaml_attribute_get_target_type (attr))) {
 				ValaDataType* _tmp13;
@@ -835,7 +835,7 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 				_tmp13 = NULL;
 				_tmp12 = NULL;
 				_tmp11 = NULL;
-				type = (_tmp13 = (_tmp12 = vala_formal_parameter_get_parameter_type (((_tmp11 = gtkaml_attribute_get_target_type (attr), VALA_IS_FORMAL_PARAMETER (_tmp11) ? ((ValaFormalParameter*) _tmp11) : NULL))), (_tmp12 == NULL) ? NULL : vala_code_node_ref (_tmp12)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp13);
+				type = (_tmp13 = (_tmp12 = vala_formal_parameter_get_parameter_type ((_tmp11 = gtkaml_attribute_get_target_type (attr), VALA_IS_FORMAL_PARAMETER (_tmp11) ? ((ValaFormalParameter*) _tmp11) : NULL)), (_tmp12 == NULL) ? NULL : vala_code_node_ref (_tmp12)), (type == NULL) ? NULL : (type = (vala_code_node_unref (type), NULL)), _tmp13);
 			} else {
 				char* _tmp14;
 				char* _tmp15;
@@ -939,7 +939,7 @@ void gtkaml_code_generator_write_setter (GtkamlCodeGenerator* self, GtkamlClassD
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->construct_body = (_tmp2 = g_strconcat (self->priv->construct_body, _tmp1 = (g_strdup_printf ("\t\t%s.%s = %s;\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (attr), _tmp0 = gtkaml_code_generator_generate_literal (self, attr))), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp2);
+	self->priv->construct_body = (_tmp2 = g_strconcat (self->priv->construct_body, _tmp1 = g_strdup_printf ("\t\t%s.%s = %s;\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (attr), _tmp0 = gtkaml_code_generator_generate_literal (self, attr)), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp2);
 	_tmp1 = (g_free (_tmp1), NULL);
 	_tmp0 = (g_free (_tmp0), NULL);
 }
@@ -965,7 +965,7 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (class_definition != NULL);
 	g_return_if_fail (signal_attr != NULL);
-	if (!(GTKAML_IS_SIMPLE_ATTRIBUTE (signal_attr))) {
+	if (!GTKAML_IS_SIMPLE_ATTRIBUTE (signal_attr)) {
 		char* _tmp0;
 		_tmp0 = NULL;
 		vala_report_error (gtkaml_class_definition_get_source_reference (class_definition), _tmp0 = g_strdup_printf ("Cannot set the signal '%s' to this value.", gtkaml_attribute_get_name (signal_attr)));
@@ -991,7 +991,7 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 			parameters_joined = (_tmp6 = string_substring (body, (glong) 1, g_utf8_strlen (body, -1) - 2), parameters_joined = (g_free (parameters_joined), NULL), _tmp6);
 			_tmp8 = NULL;
 			_tmp7 = NULL;
-			self->priv->construct_body = (_tmp8 = g_strconcat (self->priv->construct_body, _tmp7 = (g_strdup_printf ("\t\t%s.%s += %s;\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (signal_attr), parameters_joined)), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp8);
+			self->priv->construct_body = (_tmp8 = g_strconcat (self->priv->construct_body, _tmp7 = g_strdup_printf ("\t\t%s.%s += %s;\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (signal_attr), parameters_joined), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp8);
 			_tmp7 = (g_free (_tmp7), NULL);
 			(simple_attribute == NULL) ? NULL : (simple_attribute = (g_object_unref (simple_attribute), NULL));
 			(the_signal == NULL) ? NULL : (the_signal = (vala_code_node_unref (the_signal), NULL));
@@ -1052,19 +1052,19 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 		_tmp20 = NULL;
 		_tmp19 = NULL;
 		_tmp18 = NULL;
-		parameters_joined = (_tmp20 = g_strconcat (parameters_joined, _tmp19 = (g_strconcat (", ", _tmp18 = g_strjoinv (",", parameter_names), NULL)), NULL), parameters_joined = (g_free (parameters_joined), NULL), _tmp20);
+		parameters_joined = (_tmp20 = g_strconcat (parameters_joined, _tmp19 = g_strconcat (", ", _tmp18 = g_strjoinv (",", parameter_names), NULL), NULL), parameters_joined = (g_free (parameters_joined), NULL), _tmp20);
 		_tmp19 = (g_free (_tmp19), NULL);
 		_tmp18 = (g_free (_tmp18), NULL);
 		_tmp22 = NULL;
 		_tmp21 = NULL;
-		self->priv->construct_body = (_tmp22 = g_strconcat (self->priv->construct_body, _tmp21 = (g_strdup_printf ("\t\t%s.%s += (%s) => { %s; };\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (signal_attr), parameters_joined, gtkaml_simple_attribute_get_value (simple_attribute))), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp22);
+		self->priv->construct_body = (_tmp22 = g_strconcat (self->priv->construct_body, _tmp21 = g_strdup_printf ("\t\t%s.%s += (%s) => { %s; };\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (signal_attr), parameters_joined, gtkaml_simple_attribute_get_value (simple_attribute)), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp22);
 		_tmp21 = (g_free (_tmp21), NULL);
 	} else {
 		char* _tmp24;
 		char* _tmp23;
 		_tmp24 = NULL;
 		_tmp23 = NULL;
-		self->priv->construct_body = (_tmp24 = g_strconcat (self->priv->construct_body, _tmp23 = (g_strdup_printf ("\t\t%s.%s += %s => { %s; };\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (signal_attr), parameters_joined, gtkaml_simple_attribute_get_value (simple_attribute))), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp24);
+		self->priv->construct_body = (_tmp24 = g_strconcat (self->priv->construct_body, _tmp23 = g_strdup_printf ("\t\t%s.%s += %s => { %s; };\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (signal_attr), parameters_joined, gtkaml_simple_attribute_get_value (simple_attribute)), NULL), self->priv->construct_body = (g_free (self->priv->construct_body), NULL), _tmp24);
 		_tmp23 = (g_free (_tmp23), NULL);
 	}
 	(simple_attribute == NULL) ? NULL : (simple_attribute = (g_object_unref (simple_attribute), NULL));
@@ -1083,7 +1083,7 @@ void gtkaml_code_generator_add_code (GtkamlCodeGenerator* self, const char* valu
 	g_return_if_fail (value != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->priv->code = (_tmp1 = g_strconcat (self->priv->code, _tmp0 = (g_strconcat (value, "\n", NULL)), NULL), self->priv->code = (g_free (self->priv->code), NULL), _tmp1);
+	self->priv->code = (_tmp1 = g_strconcat (self->priv->code, _tmp0 = g_strconcat (value, "\n", NULL), NULL), self->priv->code = (g_free (self->priv->code), NULL), _tmp1);
 	_tmp0 = (g_free (_tmp0), NULL);
 }
 
