@@ -111,7 +111,7 @@ void gtkaml_implicits_resolver_resolve (GtkamlImplicitsResolver* self, GtkamlCla
 	g_return_if_fail (class_definition != NULL);
 	/*determine which constructor shall we use
 	references don't have to be constructed*/
-	if (!(GTKAML_IS_REFERENCE_CLASS_DEFINITION (class_definition))) {
+	if (!GTKAML_IS_REFERENCE_CLASS_DEFINITION (class_definition)) {
 		gtkaml_implicits_resolver_determine_construct_method (self, class_definition);
 	}
 	/*then determine the container add function, if applicable*/
@@ -166,7 +166,7 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 			if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 				GtkamlAttribute* _tmp0;
 				_tmp0 = NULL;
-				gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL))));
+				gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type ((_tmp0 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL)));
 			}
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
@@ -188,7 +188,7 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 				if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 					GtkamlAttribute* _tmp2;
 					_tmp2 = NULL;
-					gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp2 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp2) ? ((GtkamlComplexAttribute*) _tmp2) : NULL))));
+					gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type ((_tmp2 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp2) ? ((GtkamlComplexAttribute*) _tmp2) : NULL)));
 				}
 				(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 			}
@@ -220,7 +220,7 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 				if (_tmp4) {
 					GtkamlAttribute* _tmp5;
 					_tmp5 = NULL;
-					gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp5 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp5) ? ((GtkamlComplexAttribute*) _tmp5) : NULL))));
+					gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type ((_tmp5 = attr, GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp5) ? ((GtkamlComplexAttribute*) _tmp5) : NULL)));
 				}
 				first = FALSE;
 				(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
@@ -276,7 +276,7 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 					if (_tmp1) {
 						GtkamlAttribute* _tmp2;
 						_tmp2 = NULL;
-						_tmp0 = _vala_strcmp0 (gtkaml_simple_attribute_get_value (((_tmp2 = attr, GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp2) ? ((GtkamlSimpleAttribute*) _tmp2) : NULL))), "true") == 0;
+						_tmp0 = _vala_strcmp0 (gtkaml_simple_attribute_get_value ((_tmp2 = attr, GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp2) ? ((GtkamlSimpleAttribute*) _tmp2) : NULL)), "true") == 0;
 					} else {
 						_tmp0 = FALSE;
 					}
@@ -402,7 +402,7 @@ static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicit
 					if (_tmp1) {
 						GtkamlAttribute* _tmp2;
 						_tmp2 = NULL;
-						_tmp0 = _vala_strcmp0 (gtkaml_simple_attribute_get_value (((_tmp2 = attr, GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp2) ? ((GtkamlSimpleAttribute*) _tmp2) : NULL))), "true") == 0;
+						_tmp0 = _vala_strcmp0 (gtkaml_simple_attribute_get_value ((_tmp2 = attr, GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp2) ? ((GtkamlSimpleAttribute*) _tmp2) : NULL)), "true") == 0;
 					} else {
 						_tmp0 = FALSE;
 					}
@@ -500,14 +500,14 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 		ValaObjectTypeSymbol* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		base_types = (_tmp1 = vala_class_get_base_types (((_tmp0 = container_class_holding_methods, VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL))), (base_types == NULL) ? NULL : (base_types = (gee_collection_object_unref (base_types), NULL)), _tmp1);
+		base_types = (_tmp1 = vala_class_get_base_types ((_tmp0 = container_class_holding_methods, VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL)), (base_types == NULL) ? NULL : (base_types = (gee_collection_object_unref (base_types), NULL)), _tmp1);
 	} else {
 		if (VALA_IS_INTERFACE (container_class_holding_methods)) {
 			GeeList* _tmp3;
 			ValaObjectTypeSymbol* _tmp2;
 			_tmp3 = NULL;
 			_tmp2 = NULL;
-			base_types = (_tmp3 = vala_interface_get_prerequisites (((_tmp2 = container_class_holding_methods, VALA_IS_INTERFACE (_tmp2) ? ((ValaInterface*) _tmp2) : NULL))), (base_types == NULL) ? NULL : (base_types = (gee_collection_object_unref (base_types), NULL)), _tmp3);
+			base_types = (_tmp3 = vala_interface_get_prerequisites ((_tmp2 = container_class_holding_methods, VALA_IS_INTERFACE (_tmp2) ? ((ValaInterface*) _tmp2) : NULL)), (base_types == NULL) ? NULL : (base_types = (gee_collection_object_unref (base_types), NULL)), _tmp3);
 		} else {
 			GeeList* _tmp4;
 			_tmp4 = NULL;
@@ -537,7 +537,7 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 					continue;
 				}
 				_tmp6 = NULL;
-				c = gtkaml_implicits_resolver_lookup_class (self, utns, vala_symbol_get_name ((ValaSymbol*) vala_unresolved_type_get_unresolved_symbol (((_tmp6 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp6) ? ((ValaUnresolvedType*) _tmp6) : NULL)))));
+				c = gtkaml_implicits_resolver_lookup_class (self, utns, vala_symbol_get_name ((ValaSymbol*) vala_unresolved_type_get_unresolved_symbol ((_tmp6 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp6) ? ((ValaUnresolvedType*) _tmp6) : NULL))));
 				if (c != NULL) {
 					gtkaml_implicits_resolver_lookup_container_add_methods_for_class (self, ns, container_class_implicits_entry, utns, c, methods);
 				}
@@ -624,7 +624,7 @@ void gtkaml_implicits_resolver_lookup_container_add_methods (GtkamlImplicitsReso
 				}
 				_tmp3 = NULL;
 				_tmp4 = NULL;
-				c = (_tmp4 = gtkaml_implicits_resolver_lookup_class (self, utns, vala_symbol_get_name ((ValaSymbol*) vala_unresolved_type_get_unresolved_symbol (((_tmp3 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp3) ? ((ValaUnresolvedType*) _tmp3) : NULL))))), VALA_IS_CLASS (_tmp4) ? ((ValaClass*) _tmp4) : NULL);
+				c = (_tmp4 = gtkaml_implicits_resolver_lookup_class (self, utns, vala_symbol_get_name ((ValaSymbol*) vala_unresolved_type_get_unresolved_symbol ((_tmp3 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp3) ? ((ValaUnresolvedType*) _tmp3) : NULL)))), VALA_IS_CLASS (_tmp4) ? ((ValaClass*) _tmp4) : NULL);
 				if (c != NULL) {
 					/*over inherited implicits definitions*/
 					gtkaml_implicits_resolver_lookup_container_add_methods (self, utns, c, methods);
@@ -716,17 +716,17 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 				gboolean _tmp12;
 				_tmp5 = NULL;
 				_tmp4 = NULL;
-				name = (_tmp5 = vala_symbol_get_name ((ValaSymbol*) vala_unresolved_type_get_unresolved_symbol (((_tmp4 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp4) ? ((ValaUnresolvedType*) _tmp4) : NULL)))), (_tmp5 == NULL) ? NULL : g_strdup (_tmp5));
+				name = (_tmp5 = vala_symbol_get_name ((ValaSymbol*) vala_unresolved_type_get_unresolved_symbol ((_tmp4 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp4) ? ((ValaUnresolvedType*) _tmp4) : NULL))), (_tmp5 == NULL) ? NULL : g_strdup (_tmp5));
 				ns = NULL;
 				_tmp6 = NULL;
-				if (vala_unresolved_symbol_get_inner (vala_unresolved_type_get_unresolved_symbol (((_tmp6 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp6) ? ((ValaUnresolvedType*) _tmp6) : NULL)))) != NULL) {
+				if (vala_unresolved_symbol_get_inner (vala_unresolved_type_get_unresolved_symbol ((_tmp6 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp6) ? ((ValaUnresolvedType*) _tmp6) : NULL))) != NULL) {
 					char* _tmp9;
 					const char* _tmp8;
 					ValaDataType* _tmp7;
 					_tmp9 = NULL;
 					_tmp8 = NULL;
 					_tmp7 = NULL;
-					ns = (_tmp9 = (_tmp8 = vala_symbol_get_name ((ValaSymbol*) vala_unresolved_symbol_get_inner (vala_unresolved_type_get_unresolved_symbol (((_tmp7 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp7) ? ((ValaUnresolvedType*) _tmp7) : NULL))))), (_tmp8 == NULL) ? NULL : g_strdup (_tmp8)), ns = (g_free (ns), NULL), _tmp9);
+					ns = (_tmp9 = (_tmp8 = vala_symbol_get_name ((ValaSymbol*) vala_unresolved_symbol_get_inner (vala_unresolved_type_get_unresolved_symbol ((_tmp7 = dt, VALA_IS_UNRESOLVED_TYPE (_tmp7) ? ((ValaUnresolvedType*) _tmp7) : NULL)))), (_tmp8 == NULL) ? NULL : g_strdup (_tmp8)), ns = (g_free (ns), NULL), _tmp9);
 				} else {
 					char* _tmp10;
 					_tmp10 = NULL;
@@ -740,7 +740,7 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 					ValaMember* _tmp13;
 					_tmp14 = NULL;
 					_tmp13 = NULL;
-					_tmp12 = (NULL != (result = (_tmp14 = (_tmp13 = gtkaml_implicits_resolver_member_lookup_inherited (self, otherclazz, member), VALA_IS_MEMBER (_tmp13) ? ((ValaMember*) _tmp13) : NULL), (result == NULL) ? NULL : (result = (vala_code_node_unref (result), NULL)), _tmp14)));
+					_tmp12 = NULL != (result = (_tmp14 = (_tmp13 = gtkaml_implicits_resolver_member_lookup_inherited (self, otherclazz, member), VALA_IS_MEMBER (_tmp13) ? ((ValaMember*) _tmp13) : NULL), (result == NULL) ? NULL : (result = (vala_code_node_unref (result), NULL)), _tmp14));
 				} else {
 					_tmp12 = FALSE;
 				}
@@ -785,7 +785,7 @@ static ValaObjectTypeSymbol* gtkaml_implicits_resolver_lookup_class (GtkamlImpli
 			} else {
 				_tmp3 = FALSE;
 			}
-			if ((_tmp3)) {
+			if (_tmp3) {
 				_tmp2 = TRUE;
 			} else {
 				_tmp2 = _vala_strcmp0 (vala_symbol_get_name ((ValaSymbol*) ns), xmlNamespace) == 0;
