@@ -35,30 +35,6 @@
 #include <vala/valaformalparameter.h>
 
 
-#define GTKAML_TYPE_KEY_FILE_WRAPPER (gtkaml_key_file_wrapper_get_type ())
-#define GTKAML_KEY_FILE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTKAML_TYPE_KEY_FILE_WRAPPER, GtkamlKeyFileWrapper))
-#define GTKAML_KEY_FILE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GTKAML_TYPE_KEY_FILE_WRAPPER, GtkamlKeyFileWrapperClass))
-#define GTKAML_IS_KEY_FILE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTKAML_TYPE_KEY_FILE_WRAPPER))
-#define GTKAML_IS_KEY_FILE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GTKAML_TYPE_KEY_FILE_WRAPPER))
-#define GTKAML_KEY_FILE_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GTKAML_TYPE_KEY_FILE_WRAPPER, GtkamlKeyFileWrapperClass))
-
-typedef struct _GtkamlKeyFileWrapper GtkamlKeyFileWrapper;
-typedef struct _GtkamlKeyFileWrapperClass GtkamlKeyFileWrapperClass;
-typedef struct _GtkamlKeyFileWrapperPrivate GtkamlKeyFileWrapperPrivate;
-
-/**
- * GObject-ification of KeyFile
- */
-struct _GtkamlKeyFileWrapper {
-	GObject parent_instance;
-	GtkamlKeyFileWrapperPrivate * priv;
-	GKeyFile* key_file;
-};
-
-struct _GtkamlKeyFileWrapperClass {
-	GObjectClass parent_class;
-};
-
 
 
 enum  {
@@ -69,14 +45,9 @@ static void gtkaml_implicits_parameter_finalize (GObject* obj);
 enum  {
 	GTKAML_KEY_FILE_WRAPPER_DUMMY_PROPERTY
 };
-static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, const char* group, const char* key);
-static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* self, const char* group, const char* key, int* result_length1);
-static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_construct (GType object_type);
-static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void);
 static GObject * gtkaml_key_file_wrapper_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer gtkaml_key_file_wrapper_parent_class = NULL;
 static void gtkaml_key_file_wrapper_finalize (GObject* obj);
-static GType gtkaml_key_file_wrapper_get_type (void);
 struct _GtkamlImplicitsStorePrivate {
 	GeeList* implicits_dirs;
 	GeeMap* loaded_ns;
@@ -137,7 +108,7 @@ GType gtkaml_implicits_parameter_get_type (void) {
 }
 
 
-static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, const char* group, const char* key) {
+gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, const char* group, const char* key) {
 	GError * inner_error;
 	g_return_val_if_fail (self != NULL, FALSE);
 	g_return_val_if_fail (group != NULL, FALSE);
@@ -174,7 +145,7 @@ static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, con
 }
 
 
-static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* self, const char* group, const char* key, int* result_length1) {
+char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* self, const char* group, const char* key, int* result_length1) {
 	GError * inner_error;
 	g_return_val_if_fail (self != NULL, NULL);
 	g_return_val_if_fail (group != NULL, NULL);
@@ -222,14 +193,14 @@ static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* sel
 /**
  * GObject-ification of KeyFile
  */
-static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_construct (GType object_type) {
+GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_construct (GType object_type) {
 	GtkamlKeyFileWrapper * self;
 	self = g_object_newv (object_type, 0, NULL);
 	return self;
 }
 
 
-static GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void) {
+GtkamlKeyFileWrapper* gtkaml_key_file_wrapper_new (void) {
 	return gtkaml_key_file_wrapper_construct (GTKAML_TYPE_KEY_FILE_WRAPPER);
 }
 
@@ -271,7 +242,7 @@ static void gtkaml_key_file_wrapper_finalize (GObject* obj) {
 }
 
 
-static GType gtkaml_key_file_wrapper_get_type (void) {
+GType gtkaml_key_file_wrapper_get_type (void) {
 	static GType gtkaml_key_file_wrapper_type_id = 0;
 	if (gtkaml_key_file_wrapper_type_id == 0) {
 		static const GTypeInfo g_define_type_info = { sizeof (GtkamlKeyFileWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_key_file_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlKeyFileWrapper), 0, (GInstanceInitFunc) gtkaml_key_file_wrapper_instance_init, NULL };
