@@ -272,7 +272,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				_tmp14 = NULL;
 				_tmp13 = NULL;
 				_tmp12 = NULL;
-				message = (_tmp14 = g_strconcat (message, _tmp13 = (g_strconcat ((_tmp12 = (GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i))->name, ", ", NULL)), NULL), message = (g_free (message), NULL), _tmp14);
+				message = (_tmp14 = g_strconcat (message, _tmp13 = g_strconcat ((_tmp12 = (GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i))->name, ", ", NULL), NULL), message = (g_free (message), NULL), _tmp14);
 				_tmp13 = (g_free (_tmp13), NULL);
 				(_tmp12 == NULL) ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL));
 			}
@@ -281,7 +281,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				GtkamlImplicitsParameter* _tmp15;
 				_tmp16 = NULL;
 				_tmp15 = NULL;
-				message = (_tmp16 = g_strconcat (message, ((_tmp15 = (GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i))->name), NULL), message = (g_free (message), NULL), _tmp16);
+				message = (_tmp16 = g_strconcat (message, (_tmp15 = (GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i))->name, NULL), message = (g_free (message), NULL), _tmp16);
 				(_tmp15 == NULL) ? NULL : (_tmp15 = (g_object_unref (_tmp15), NULL));
 			}
 			_tmp18 = NULL;
@@ -387,7 +387,7 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 			_tmp2 = NULL;
 			_tmp1 = NULL;
 			_tmp0 = NULL;
-			message = (_tmp2 = g_strconcat (message, _tmp1 = (g_strconcat ((_tmp0 = (GtkamlImplicitsParameter*) gee_list_get (parameters, i))->name, ", ", NULL)), NULL), message = (g_free (message), NULL), _tmp2);
+			message = (_tmp2 = g_strconcat (message, _tmp1 = g_strconcat ((_tmp0 = (GtkamlImplicitsParameter*) gee_list_get (parameters, i))->name, ", ", NULL), NULL), message = (g_free (message), NULL), _tmp2);
 			_tmp1 = (g_free (_tmp1), NULL);
 			(_tmp0 == NULL) ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL));
 		}
@@ -396,7 +396,7 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 			GtkamlImplicitsParameter* _tmp3;
 			_tmp4 = NULL;
 			_tmp3 = NULL;
-			message = (_tmp4 = g_strconcat (message, ((_tmp3 = (GtkamlImplicitsParameter*) gee_list_get (parameters, i))->name), NULL), message = (g_free (message), NULL), _tmp4);
+			message = (_tmp4 = g_strconcat (message, (_tmp3 = (GtkamlImplicitsParameter*) gee_list_get (parameters, i))->name, NULL), message = (g_free (message), NULL), _tmp4);
 			(_tmp3 == NULL) ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL));
 		}
 		_tmp6 = NULL;
