@@ -156,37 +156,15 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 			dummy_file = vala_source_file_new (self->priv->context, vala_source_file_get_filename (gtkaml_source_file), FALSE, NULL);
 			sax_parser = gtkaml_sax_parser_new (self->priv->context, dummy_file);
 			root_class_definition = gtkaml_sax_parser_parse (sax_parser);
-			if (vala_report_get_errors () != 0) {
-				(dummy_file == NULL) ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL));
-				(sax_parser == NULL) ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL));
-				(root_class_definition == NULL) ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL));
-				return;
-			}
 			implicitsResolver = gtkaml_implicits_resolver_new (self->priv->context, self->priv->implicits_store);
 			gtkaml_implicits_resolver_resolve (implicitsResolver, (GtkamlClassDefinition*) root_class_definition);
-			if (vala_report_get_errors () != 0) {
-				(dummy_file == NULL) ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL));
-				(sax_parser == NULL) ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL));
-				(root_class_definition == NULL) ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL));
-				(implicitsResolver == NULL) ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL));
-				return;
-			}
 			code_generator = gtkaml_code_generator_new (self->priv->context);
 			gtkaml_code_generator_generate (code_generator, (GtkamlClassDefinition*) root_class_definition);
-			if (vala_report_get_errors () != 0) {
-				(dummy_file == NULL) ? NULL : (dummy_file = (vala_source_file_unref (dummy_file), NULL));
-				(sax_parser == NULL) ? NULL : (sax_parser = (g_object_unref (sax_parser), NULL));
-				(root_class_definition == NULL) ? NULL : (root_class_definition = (g_object_unref (root_class_definition), NULL));
-				(implicitsResolver == NULL) ? NULL : (implicitsResolver = (g_object_unref (implicitsResolver), NULL));
-				(code_generator == NULL) ? NULL : (code_generator = (g_object_unref (code_generator), NULL));
-				return;
-			}
 			vala_contents = gtkaml_code_generator_yield (code_generator);
 			if (vala_contents != NULL) {
 				char* _tmp0;
 				char* _tmp1;
 				char* vala_filename;
-				gboolean _tmp2;
 				_tmp0 = NULL;
 				_tmp1 = NULL;
 				vala_filename = (_tmp1 = g_strconcat (_tmp0 = g_strndup (vala_source_file_get_filename (gtkaml_source_file), (gsize) (g_utf8_strlen (vala_source_file_get_filename (gtkaml_source_file), -1) - g_utf8_strlen (".gtkaml", -1))), ".vala", NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
@@ -206,13 +184,7 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 				}
 				vala_source_file_set_filename (gtkaml_source_file, vala_filename);
 				VALA_CODE_VISITOR_CLASS (gtkaml_parser_parent_class)->visit_source_file ((ValaCodeVisitor*) VALA_PARSER (self), gtkaml_source_file);
-				_tmp2 = FALSE;
-				if (vala_report_get_errors () == 0) {
-					_tmp2 = !vala_code_context_get_save_temps (self->priv->context);
-				} else {
-					_tmp2 = FALSE;
-				}
-				if (_tmp2) {
+				if (!vala_code_context_get_save_temps (self->priv->context)) {
 					g_unlink (vala_filename);
 				}
 				vala_filename = (g_free (vala_filename), NULL);
@@ -242,10 +214,10 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 			return;
 		}
 	} else {
-		char* _tmp3;
-		_tmp3 = NULL;
-		vala_report_error (NULL, _tmp3 = g_strdup_printf ("%s not found", vala_source_file_get_filename (gtkaml_source_file)));
-		_tmp3 = (g_free (_tmp3), NULL);
+		char* _tmp2;
+		_tmp2 = NULL;
+		vala_report_error (NULL, _tmp2 = g_strdup_printf ("%s not found", vala_source_file_get_filename (gtkaml_source_file)));
+		_tmp2 = (g_free (_tmp2), NULL);
 	}
 }
 
