@@ -271,15 +271,6 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 				_tmp8 = NULL;
 				gtkaml_sax_parser_set_root_class_definition (self, _tmp8 = gtkaml_sax_parser_get_root_definition (self, clazz, attrs, prefix));
 				(_tmp8 == NULL) ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL));
-				if (vala_report_get_errors () > 0) {
-					gtkaml_sax_parser_stop_parsing (self);
-					(nss == NULL) ? NULL : (nss = (gee_collection_object_unref (nss), NULL));
-					(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
-					(attrs == NULL) ? NULL : (attrs = (gee_collection_object_unref (attrs), NULL));
-					(state == NULL) ? NULL : (state = (g_object_unref (state), NULL));
-					(source_reference == NULL) ? NULL : (source_reference = (vala_source_reference_unref (source_reference), NULL));
-					return;
-				}
 				_tmp9 = NULL;
 				gtkaml_state_stack_push (self->priv->_states, _tmp9 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, (GtkamlClassDefinition*) self->priv->_root_class_definition, NULL, NULL));
 				(_tmp9 == NULL) ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL));
@@ -341,15 +332,6 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 					(_tmp19 == NULL) ? NULL : (_tmp19 = (g_object_unref (_tmp19), NULL));
 					(attribute_parent_class_definition == NULL) ? NULL : (attribute_parent_class_definition = (g_object_unref (attribute_parent_class_definition), NULL));
 				}
-				if (vala_report_get_errors () > 0) {
-					gtkaml_sax_parser_stop_parsing (self);
-					(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
-					fqan = (g_free (fqan), NULL);
-					(attrs == NULL) ? NULL : (attrs = (gee_collection_object_unref (attrs), NULL));
-					(state == NULL) ? NULL : (state = (g_object_unref (state), NULL));
-					(source_reference == NULL) ? NULL : (source_reference = (vala_source_reference_unref (source_reference), NULL));
-					return;
-				}
 				(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
 				fqan = (g_free (fqan), NULL);
 				break;
@@ -407,16 +389,6 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 				gtkaml_state_set_attribute (state, (GtkamlAttribute*) attr);
 				/*add the attribute into the parent container*/
 				gtkaml_class_definition_add_attribute (gtkaml_state_get_class_definition (state), (GtkamlAttribute*) attr);
-				if (vala_report_get_errors () > 0) {
-					gtkaml_sax_parser_stop_parsing (self);
-					(clazz == NULL) ? NULL : (clazz = (vala_code_node_unref (clazz), NULL));
-					(attribute_value_definition == NULL) ? NULL : (attribute_value_definition = (g_object_unref (attribute_value_definition), NULL));
-					(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
-					(attrs == NULL) ? NULL : (attrs = (gee_collection_object_unref (attrs), NULL));
-					(state == NULL) ? NULL : (state = (g_object_unref (state), NULL));
-					(source_reference == NULL) ? NULL : (source_reference = (vala_source_reference_unref (source_reference), NULL));
-					return;
-				}
 				_tmp27 = NULL;
 				gtkaml_state_stack_push (self->priv->_states, _tmp27 = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_CONTAINER_STATE, attribute_value_definition, NULL, NULL));
 				(_tmp27 == NULL) ? NULL : (_tmp27 = (g_object_unref (_tmp27), NULL));
@@ -477,20 +449,20 @@ void gtkaml_sax_parser_end_element (GtkamlSAXParser* self, const char* localname
 	_tmp1 = FALSE;
 	_tmp2 = FALSE;
 	_tmp3 = FALSE;
-	if ((last_state != NULL)) {
-		_tmp3 = (gtkaml_state_get_state_id (last_state) == GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE);
+	if (last_state != NULL) {
+		_tmp3 = gtkaml_state_get_state_id (last_state) == GTKAML_STATE_ID_SAX_PARSER_ATTRIBUTE_STATE;
 	} else {
 		_tmp3 = FALSE;
 	}
 	if (_tmp3) {
-		_tmp2 = (gtkaml_state_get_attribute (last_state) == NULL);
+		_tmp2 = gtkaml_state_get_attribute (last_state) == NULL;
 	} else {
 		_tmp2 = FALSE;
 	}
 	if (_tmp2) {
 		char* _tmp4;
 		_tmp4 = NULL;
-		_tmp1 = (_vala_strcmp0 (gtkaml_state_get_attribute_name (last_state), _tmp4 = g_strconcat (self->gtkaml_prefix, ".preconstruct", NULL)) != 0);
+		_tmp1 = _vala_strcmp0 (gtkaml_state_get_attribute_name (last_state), _tmp4 = g_strconcat (self->gtkaml_prefix, ".preconstruct", NULL)) != 0;
 		_tmp4 = (g_free (_tmp4), NULL);
 	} else {
 		_tmp1 = FALSE;
@@ -498,7 +470,7 @@ void gtkaml_sax_parser_end_element (GtkamlSAXParser* self, const char* localname
 	if (_tmp1) {
 		char* _tmp5;
 		_tmp5 = NULL;
-		_tmp0 = (_vala_strcmp0 (gtkaml_state_get_attribute_name (last_state), _tmp5 = g_strconcat (self->gtkaml_prefix, ".construct", NULL)) != 0);
+		_tmp0 = _vala_strcmp0 (gtkaml_state_get_attribute_name (last_state), _tmp5 = g_strconcat (self->gtkaml_prefix, ".construct", NULL)) != 0;
 		_tmp5 = (g_free (_tmp5), NULL);
 	} else {
 		_tmp0 = FALSE;
@@ -612,7 +584,7 @@ static void gtkaml_sax_parser_parse_attribute_content_as_text (GtkamlSAXParser*
 						_tmp12 = NULL;
 						_tmp11 = NULL;
 						_tmp10 = NULL;
-						gtkaml_simple_attribute_set_value (((_tmp10 = gtkaml_state_get_attribute (state), GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp10) ? ((GtkamlSimpleAttribute*) _tmp10) : NULL)), _tmp12 = g_strconcat (gtkaml_simple_attribute_get_value (((_tmp10 = gtkaml_state_get_attribute (state), GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp10) ? ((GtkamlSimpleAttribute*) _tmp10) : NULL))), _tmp11 = (g_strconcat ("\n", content, NULL)), NULL));
+						gtkaml_simple_attribute_set_value ((_tmp10 = gtkaml_state_get_attribute (state), GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp10) ? ((GtkamlSimpleAttribute*) _tmp10) : NULL), _tmp12 = g_strconcat (gtkaml_simple_attribute_get_value ((_tmp10 = gtkaml_state_get_attribute (state), GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp10) ? ((GtkamlSimpleAttribute*) _tmp10) : NULL)), _tmp11 = g_strconcat ("\n", content, NULL), NULL));
 						_tmp12 = (g_free (_tmp12), NULL);
 						_tmp11 = (g_free (_tmp11), NULL);
 					} else {
@@ -678,7 +650,7 @@ static ValaClass* gtkaml_sax_parser_lookup_class (GtkamlSAXParser* self, const c
 					_tmp3 = NULL;
 					_tmp2 = NULL;
 					_tmp4 = NULL;
-					return (_tmp4 = (_tmp3 = ((_tmp2 = s, VALA_IS_CLASS (_tmp2) ? ((ValaClass*) _tmp2) : NULL)), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), (_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL)), _tmp4);
+					return (_tmp4 = (_tmp3 = (_tmp2 = s, VALA_IS_CLASS (_tmp2) ? ((ValaClass*) _tmp2) : NULL), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3)), (s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL)), (ns == NULL) ? NULL : (ns = (vala_code_node_unref (ns), NULL)), (_ns_it == NULL) ? NULL : (_ns_it = (gee_collection_object_unref (_ns_it), NULL)), _tmp4);
 				}
 				(s == NULL) ? NULL : (s = (vala_code_node_unref (s), NULL));
 			}
@@ -902,7 +874,7 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 				} else {
 					_tmp2 = _vala_strcmp0 (attr->localname, "private") == 0;
 				}
-				if ((_tmp2)) {
+				if (_tmp2) {
 					char* _tmp6;
 					const char* _tmp5;
 					if (identifier != NULL) {
@@ -1159,7 +1131,7 @@ static GeeList* gtkaml_sax_parser_parse_attributes (GtkamlSAXParser* self, char*
 			_tmp10 = NULL;
 			attr->value = (_tmp10 = g_strndup (attr->value, (gsize) (g_utf8_strlen (attr->value, -1) - g_utf8_strlen (end, -1))), attr->value = (g_free (attr->value), NULL), _tmp10);
 			gee_collection_add ((GeeCollection*) attribute_list, attr);
-			walker = walker + (5);
+			walker = walker + 5;
 			(attr == NULL) ? NULL : (attr = (g_object_unref (attr), NULL));
 		}
 	}
@@ -1224,7 +1196,7 @@ static GeeList* gtkaml_sax_parser_parse_namespaces (GtkamlSAXParser* self, char*
 				}
 			}
 			gee_collection_add ((GeeCollection*) namespace_list, ns);
-			walker = walker + (2);
+			walker = walker + 2;
 			(ns == NULL) ? NULL : (ns = (g_object_unref (ns), NULL));
 		}
 	}
