@@ -58,7 +58,7 @@ GtkamlState* gtkaml_state_stack_peek (GtkamlStateStack* self, gint backtrack) {
 	g_return_val_if_fail (self != NULL, NULL);
 	element = NULL;
 	_tmp0 = NULL;
-	size = gee_collection_get_size ((GeeCollection*) ((_tmp0 = self->priv->_array_list, GEE_IS_LIST (_tmp0) ? ((GeeList*) _tmp0) : NULL)));
+	size = gee_collection_get_size ((GeeCollection*) (_tmp0 = self->priv->_array_list, GEE_IS_LIST (_tmp0) ? ((GeeList*) _tmp0) : NULL));
 	if (size != 0) {
 		GtkamlState* _tmp1;
 		_tmp1 = NULL;
